@@ -21,7 +21,7 @@ class CollectGitPlugin(CollectorPlugin):
     Class to copy git repositories
     """
 
-    supported_purl_types = ["git", "gitlab", "github", "golang"]
+    supported_purl_types = ["git", "gitlab", "github"]
     required_commands = ["git"]
 
     def get_version(self) -> str:  # pylint: disable=duplicate-code
